Page MenuHomePhabricator

D11946.id.diff
No OneTemporary

D11946.id.diff

diff --git a/lib/types/media-types.js b/lib/types/media-types.js
--- a/lib/types/media-types.js
+++ b/lib/types/media-types.js
@@ -721,7 +721,7 @@
+dimensions: Dimensions,
+thumbHash: ?string,
};
-// old message formats (native codeVersion < FUTURE_CODE_VERSION) used holder
+// old message formats (native codeVersion < NEXT_CODE_VERSION) used holder
// new format uses blobURI. Effectively, they both mean blob URI
export type EncryptedImage =
| { ...EncryptedImageCommons, +holder: string }
@@ -775,7 +775,7 @@
+thumbnailEncryptionKey: string,
+thumbnailThumbHash: ?string,
};
-// old message formats (native codeVersion < FUTURE_CODE_VERSION) used holder
+// old message formats (native codeVersion < NEXT_CODE_VERSION) used holder
// new format uses blobURI. Effectively, they both mean blob URI
export type EncryptedVideo =
| { ...EncryptedVideoCommons, +holder: string, +thumbnailHolder: string }

File Metadata

Mime Type
text/plain
Expires
Sun, Dec 22, 7:31 PM (2 h, 32 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
2692249
Default Alt Text
D11946.id.diff (1 KB)

Event Timeline
diff --git a/lib/media/media-utils.js b/lib/media/media-utils.js
--- a/lib/media/media-utils.js
+++ b/lib/media/media-utils.js
@@ -3,7 +3,7 @@
import invariant from 'invariant';
import {
- FUTURE_CODE_VERSION,
+ NEXT_CODE_VERSION,
hasMinCodeVersion,
} from '../shared/version-utils.js';
import type { PlatformDetails } from '../types/device-types.js';
@@ -62,7 +62,7 @@
);
}
/** Clients before FUTURE_CODE_VERSION understand only `holder`
* and `thumbnailHolder` fields, while newer clients understand `blobURI`
* and `thumbnailBlobURI`. This function formats the multimedia message
* to be understandable by clients based on their version
@@ -72,7 +72,7 @@
platformDetails: ?PlatformDetails,
): RawMediaMessageInfo {
const isBlobURISupported = hasMinCodeVersion(platformDetails, {
- native: FUTURE_CODE_VERSION,
+ native: NEXT_CODE_VERSION,
});
const media = rawMessageInfo.media.map(singleMedia => {
if (singleMedia.type === 'photo' || singleMedia.type === 'video') {
@@ -62,7 +62,7 @@
);
}
-/** Clients before FUTURE_CODE_VERSION understand only `holder`
+/** Clients before NEXT_CODE_VERSION understand only `holder`
* and `thumbnailHolder` fields, while newer clients understand `blobURI`
* and `thumbnailBlobURI`. This function formats the multimedia message